Documentation
¶
Index ¶
- type Options
- func (opts Options) Application(env anser.Environment, evgEnv evergreen.Environment) (*anser.Application, error)
- func (opts Options) CustomApplication(env anser.Environment, conf *model.ConfigurationManualMigration) (*anser.Application, error)
- func (opts Options) Setup(ctx context.Context) (anser.Environment, error)
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Options ¶
type Options struct {
Limit int
Target int
Workers int
DryRun bool
IDs []string
Period time.Duration
Database string
Session db.Session
}
func (Options) Application ¶
func (opts Options) Application(env anser.Environment, evgEnv evergreen.Environment) (*anser.Application, error)
Application is where the migrations are registered and defined, before being handed off to another calling environment for execution. See the anser documentation and the anser/example_test.go for an example.
func (Options) CustomApplication ¶
func (opts Options) CustomApplication(env anser.Environment, conf *model.ConfigurationManualMigration) (*anser.Application, error)
Source Files
¶
- admin_events.go
- admin_maps.go
- anser.go
- bson_object_id_to_string.go
- custom_migration_factory.go
- distro_security_groups.go
- event_rtype_migration.go
- event_set_processed.go
- github_hook.go
- legacy_notifications.go
- perf_copy_variant.go
- project_aliases.go
- set_default_branch.go
- set_spawnhost_preference.go
- testresults.go
- zero_date_fix.go
Click to show internal directories.
Click to hide internal directories.